@@ -101,9 +101,12 @@ class AlgorithmContainerConfigParser:
                 else:
                     param_init_lines += ('            {} = {}({})\n'.format(each_input_param_name, self.input_params[each_input_param_name]['type'],  each_input_param_name))
             function_lines =  "            out = {}.{}(".format(self.service_filename, self.service_interface)
-            for each_input_param_name in list(self.input_params.keys())[:-1]:
-                function_lines += (each_input_param_name + ', ')
-            function_lines += (list(self.input_params.keys())[-1] + ")\n")
+            if len(list(self.input_params.keys())) == 0:
+                function_lines += ")\n"
+            else:
+                for each_input_param_name in list(self.input_params.keys())[:-1]:
+                    function_lines += (each_input_param_name + ', ')
+                function_lines += (list(self.input_params.keys())[-1] + ")\n")
 
             for each_output_param in self.output_params:
                 if self.output_params[each_output_param]['type'] == 'path':
